@@ -17,19 +17,28 @@ class CkanNose(Plugin):
         # import needs to be here or setup happens too early
         import ckan.model as model
 
+        if 'new_tests' in repr(ctx):
+            # We don't want to do the stuff below for new-style tests.
+            if not CkanNose.settings.reset_database:
+                model.repo.tables_created_and_initialised = True
+            return
+
         if isclass(ctx):
             if hasattr(ctx, "no_db") and ctx.no_db:
                 return
-            if self.is_first_test or CkanNose.settings.ckan_migration:
+            if (not CkanNose.settings.reset_database
+                    and not CkanNose.settings.ckan_migration):
+                model.Session.close_all()
+                model.repo.tables_created_and_initialised = True
+                model.repo.rebuild_db()
+                self.is_first_test = False
+            elif self.is_first_test or CkanNose.settings.ckan_migration:
                 model.Session.close_all()
                 model.repo.clean_db()
                 self.is_first_test = False
                 if CkanNose.settings.ckan_migration:
                     model.Session.close_all()
                     model.repo.upgrade_db()
-            # init_db is run at the start of every class because
-            # when you use an in-memory sqlite db, it appears that
-            # the db is destroyed after every test when you Session.Remove().
 
             ## This is to make sure the configuration is run again.
             ## Plugins use configure to make their own tables and they
@@ -38,7 +47,10 @@ class CkanNose(Plugin):
             from ckan.plugins.interfaces import IConfigurable
             for plugin in PluginImplementations(IConfigurable):
                 plugin.configure(config)
-            
+
+            # init_db is run at the start of every class because
+            # when you use an in-memory sqlite db, it appears that
+            # the db is destroyed after every test when you Session.Remove().
             model.repo.init_db()
 
     def options(self, parser, env):
@@ -62,6 +74,11 @@ class CkanNose(Plugin):
             dest='segments',
             help='A string containing a hex digits that represent which of'
                  'the 16 test segments to run. i.e 15af will run segments 1,5,a,f')
+        parser.add_option(
+            '--reset-db',
+            action='store_true',
+            dest='reset_database',
+            help='drop database and reinitialize before tests are run')
 
     def wantClass(self, cls):
         name = cls.__name__
