@@ -323,7 +323,8 @@ class GroupController(base.BaseController):
                 'extras': search_extras
             }
 
-            query = get_action('package_search')(context, data_dict)
+            context_ = dict((k, v) for (k, v) in context.items() if k != 'schema')
+            query = get_action('package_search')(context_, data_dict)
 
             c.page = h.Page(
                 collection=query['results'],
@@ -363,6 +364,9 @@ class GroupController(base.BaseController):
 
         group_type = self._get_group_type(id.split('@')[0])
 
+        if group_type is None:
+            abort(404, _('Organization not found'))
+
         if group_type != 'organization':
             # FIXME: better error
             raise Exception('Must be an organization')
@@ -638,12 +642,19 @@ class GroupController(base.BaseController):
 
         #self._check_access('group_delete', context, {'id': id})
         try:
+            c.group_dict = self._action('group_show')(context, {'id': id})
+            group_type = 'organization' if c.group_dict['is_organization'] else 'group'
+            c.roles = self._action('member_roles_list')(
+                context, {'group_type': group_type}
+            )
+
             if request.method == 'POST':
                 data_dict = clean_dict(dict_fns.unflatten(
                     tuplize_dict(parse_params(request.params))))
                 data_dict['id'] = id
 
                 email = data_dict.get('email')
+
                 if email:
                     user_data_dict = {
                         'email': email,
@@ -656,6 +667,8 @@ class GroupController(base.BaseController):
                     data_dict['username'] = user_dict['name']
 
                 c.group_dict = self._action('group_member_create')(context, data_dict)
+
+
                 self._redirect_to(controller='group', action='members', id=id)
             else:
                 user = request.params.get('user')
@@ -664,11 +677,6 @@ class GroupController(base.BaseController):
                     c.user_role = new_authz.users_role_for_group_or_org(id, user) or 'member'
                 else:
                     c.user_role = 'member'
-                c.group_dict = self._action('group_show')(context, {'id': id})
-                group_type = 'organization' if c.group_dict['is_organization'] else 'group'
-                c.roles = self._action('member_roles_list')(
-                    context, {'group_type': group_type}
-                )
         except NotAuthorized:
             abort(401, _('Unauthorized to add member to group %s') % '')
         except NotFound:
