@@ -1,6 +1,5 @@
 import logging
 from urllib import quote
-from urlparse import urlparse
 
 from pylons import config
 
@@ -15,7 +14,7 @@ import ckan.lib.mailer as mailer
 import ckan.lib.navl.dictization_functions as dictization_functions
 import ckan.plugins as p
 
-from ckan.common import _, c, g, request
+from ckan.common import _, c, g, request, response
 
 log = logging.getLogger(__name__)
 
@@ -217,20 +216,12 @@ class UserController(base.BaseController):
             error_summary = e.error_summary
             return self.new(data_dict, errors, error_summary)
         if not c.user:
-            # Redirect to a URL picked up by repoze.who which performs the
-            # login
-            login_url = self._get_repoze_handler('login_handler_path')
-
-            # We need to pass the logged in URL as came_from parameter
-            # otherwise we lose the language setting
-            came_from = h.url_for(controller='user', action='logged_in',
-                                  __ckan_no_root=True)
-            redirect_url = '{0}?login={1}&password={2}&came_from={3}'
-            h.redirect_to(redirect_url.format(
-                login_url,
-                str(data_dict['name']),
-                quote(data_dict['password1'].encode('utf-8')),
-                came_from))
+            # log the user in programatically
+            rememberer = request.environ['repoze.who.plugins']['friendlyform']
+            identity = {'repoze.who.userid': data_dict['name']}
+            response.headerlist += rememberer.remember(request.environ,
+                                                       identity)
+            h.redirect_to(controller='user', action='me', __ckan_no_root=True)
         else:
             # #1799 User has managed to register whilst logged in - warn user
             # they are not re-logged in as new user.
@@ -356,7 +347,7 @@ class UserController(base.BaseController):
     def logged_in(self):
         # redirect if needed
         came_from = request.params.get('came_from', '')
-        if self._sane_came_from(came_from):
+        if h.url_is_local(came_from):
             return h.redirect_to(str(came_from))
 
         if c.user:
@@ -392,7 +383,7 @@ class UserController(base.BaseController):
     def logged_out(self):
         # redirect if needed
         came_from = request.params.get('came_from', '')
-        if self._sane_came_from(came_from):
+        if h.url_is_local(came_from):
             return h.redirect_to(str(came_from))
         h.redirect_to(controller='user', action='logged_out_page')
 
@@ -570,7 +561,8 @@ class UserController(base.BaseController):
             action_functions = {
                 'dataset': 'package_show',
                 'user': 'user_show',
-                'group': 'group_show'
+                'group': 'group_show',
+                'organization': 'organization_show',
             }
             action_function = logic.get_action(
                 action_functions.get(filter_type))
@@ -688,14 +680,3 @@ class UserController(base.BaseController):
                              or e.error_dict)
             h.flash_error(error_message)
         h.redirect_to(controller='user', action='read', id=id)
-
-    def _sane_came_from(self, url):
-        '''Returns True if came_from is local'''
-        if not url or (len(url) >= 2 and url.startswith('//')):
-            return False
-        parsed = urlparse(url)
-        if parsed.scheme:
-            domain = urlparse(h.url_for('/', qualified=True)).netloc
-            if domain != parsed.netloc:
-                return False
-        return True
