@@ -2,6 +2,8 @@ import re
 
 import ckan.lib.base as base
 import ckan.lib.i18n as i18n
+import ckan.lib.helpers as h
+from ckan.common import _
 
 
 class UtilController(base.BaseController):
@@ -10,7 +12,13 @@ class UtilController(base.BaseController):
     def redirect(self):
         ''' redirect to the url parameter. '''
         url = base.request.params.get('url')
-        return base.redirect(url)
+        if not url:
+            base.abort(400, _('Missing Value') + ': url')
+
+        if h.url_is_local(url):
+            return base.redirect(url)
+        else:
+            base.abort(403, _('Redirecting to external site is not allowed.'))
 
     def primer(self):
         ''' Render all html components out onto a single page.
