@@ -100,21 +100,37 @@ def mail_user(recipient, subject, body, headers={}):
     mail_recipient(recipient.display_name, recipient.email, subject,
             body, headers=headers)
 
+def get_reset_link_body(user):
+    reset_link_message = _(
+    '''You have requested your password on %(site_title)s to be reset.
 
-RESET_LINK_MESSAGE = _(
-'''You have requested your password on %(site_title)s to be reset.
+    Please click the following link to confirm this request:
 
-Please click the following link to confirm this request:
+       %(reset_link)s
+    ''')
 
-   %(reset_link)s
-''')
+    d = {
+        'reset_link': get_reset_link(user),
+        'site_title': g.site_title
+        }
+    return reset_link_message % d
 
-def make_key():
-    return uuid.uuid4().hex[:10]
+def get_invite_body(user):
+    invite_message = _(
+    '''You have been invited to %(site_title)s. A user has already been created to
+    you with the username %(user_name)s. You can change it later.
 
-def create_reset_key(user):
-    user.reset_key = unicode(make_key())
-    model.repo.commit_and_remove()
+    To accept this invite, please reset your password at:
+
+       %(reset_link)s
+    ''')
+
+    d = {
+        'reset_link': get_reset_link(user),
+        'site_title': g.site_title,
+        'user_name': user.name,
+        }
+    return invite_message % d
 
 def get_reset_link(user):
     return urljoin(g.site_url,
@@ -123,17 +139,24 @@ def get_reset_link(user):
                            id=user.id,
                            key=user.reset_key))
 
-def get_reset_link_body(user):
-    d = {
-        'reset_link': get_reset_link(user),
-        'site_title': g.site_title
-        }
-    return RESET_LINK_MESSAGE % d
-
 def send_reset_link(user):
     create_reset_key(user)
     body = get_reset_link_body(user)
-    mail_user(user, _('Reset your password'), body)
+    subject = _('Reset your password')
+    mail_user(user, subject, body)
+
+def send_invite(user):
+    create_reset_key(user)
+    body = get_invite_body(user)
+    subject = _('Invite for {site_title}'.format(site_title=g.site_title))
+    mail_user(user, subject, body)
+
+def create_reset_key(user):
+    user.reset_key = unicode(make_key())
+    model.repo.commit_and_remove()
+
+def make_key():
+    return uuid.uuid4().hex[:10]
 
 def verify_reset_link(user, key):
     if not key:
