@@ -3,6 +3,7 @@ import string
 import logging
 import collections
 import json
+import datetime
 from dateutil.parser import parse
 
 import re
@@ -107,8 +108,6 @@ class PackageSearchIndex(SearchIndex):
         if pkg_dict is None:
             return
 
-        pkg_dict['data_dict'] = json.dumps(pkg_dict)
-
         if config.get('ckan.cache_validated_datasets', True):
             package_plugin = lib_plugins.lookup_package_plugin(
                 pkg_dict.get('type'))
@@ -119,6 +118,8 @@ class PackageSearchIndex(SearchIndex):
             pkg_dict['validated_data_dict'] = json.dumps(validated_pkg_dict,
                 cls=ckan.lib.navl.dictization_functions.MissingNullEncoder)
 
+        pkg_dict['data_dict'] = json.dumps(pkg_dict)
+
         # add to string field for sorting
         title = pkg_dict.get('title')
         if title:
@@ -217,11 +218,18 @@ class PackageSearchIndex(SearchIndex):
         # be needed?  For my data not changing the keys seems to not cause a
         # problem.
         new_dict = {}
+        bogus_date = datetime.datetime(1, 1, 1)
         for key, value in pkg_dict.items():
             key = key.encode('ascii', 'ignore')
             if key.endswith('_date'):
                 try:
-                    value = parse(value).isoformat() + 'Z'
+                    date = parse(value, default=bogus_date)
+                    if date != bogus_date:
+                        value = date.isoformat() + 'Z'
+                    else:
+                        # The date field was empty, so dateutil filled it with
+                        # the default bogus date
+                        value = None
                 except ValueError:
                     continue
             new_dict[key] = value
