@@ -447,22 +447,6 @@ def get_action(action):
             fn.side_effect_free = True
         _actions[action_name] = fn
 
-
-        def replaced_action(action_name):
-            def warn(context, data_dict):
-                log.critical('Action `%s` is being called directly '
-                             'all action calls should be accessed via '
-                             'logic.get_action' % action_name)
-                return get_action(action_name)(context, data_dict)
-            return warn
-
-        # Store our wrapped function so it is available.  This is to prevent
-        # rewrapping of actions
-        module = sys.modules[_action.__module__]
-        r = replaced_action(action_name)
-        r.__replaced = fn
-        module.__dict__[action_name] = r
-
     return _actions.get(action)
 
 
