@@ -16,6 +16,10 @@
     null,
     "Следвай"
   ],
+  "Image": [
+    null,
+    "Изображение"
+  ],
   "Loading...": [
     null,
     "Зареждане...."
@@ -24,6 +28,10 @@
     null,
     "URL"
   ],
+  "Upload": [
+    null,
+    "Качване"
+  ],
   "Upload a file": [
     null,
     "Качване на файл"
