@@ -36,10 +36,22 @@
     null,
     "Oculta"
   ],
+  "Image": [
+    null,
+    "Imatge"
+  ],
   "Input is too short, must be at least one character": [
     null,
     "L'entrada de dades és massa curta, almenys ha de tenir un caràcter"
   ],
+  "Link": [
+    null,
+    "Enllaç"
+  ],
+  "Link to a URL on the internet (you can also link to an API)": [
+    null,
+    "Enllaçar a una URL a l'Internet (també podeu enllaçar a una API)"
+  ],
   "Loading...": [
     null,
     "Carregant..."
@@ -52,10 +64,30 @@
     null,
     "Acció de confirmació"
   ],
+  "Remove": [
+    null,
+    "Esborra"
+  ],
+  "Reorder resources": [
+    null,
+    "Reordenar recursos"
+  ],
+  "Reset this": [
+    null,
+    "Reiniciar"
+  ],
   "Resource uploaded": [
     null,
     "El recurs s'ha carregat"
   ],
+  "Save order": [
+    null,
+    "Desar ordre"
+  ],
+  "Saving...": [
+    null,
+    "Desant..."
+  ],
   "Show more": [
     null,
     "Mostra més"
@@ -92,10 +124,18 @@
     null,
     "Deixar de seguir"
   ],
+  "Upload": [
+    null,
+    "Carregar"
+  ],
   "Upload a file": [
     null,
     "Carregar un arxiu"
   ],
+  "Upload a file on your computer": [
+    null,
+    "Pujar un arxiu des del vostre ordinador"
+  ],
   "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
     null,
     "Esteu pujant un arxiu. Esteu segurs que voleu marxar de la pàgina i aturar la pujada?"
