@@ -16,6 +16,10 @@
     null,
     "Ikuti"
   ],
+  "Image": [
+    null,
+    "Gambar"
+  ],
   "Loading...": [
     null,
     "Memuat..."
@@ -28,6 +32,10 @@
     null,
     "Tidak ikuti"
   ],
+  "Upload": [
+    null,
+    "Unggah"
+  ],
   "Upload a file": [
     null,
     "Unggah file"
