@@ -16,6 +16,10 @@
     null,
     "Odoberať"
   ],
+  "Image": [
+    null,
+    "Obrázok"
+  ],
   "Loading...": [
     null,
     "Prebieha načítavanie..."
@@ -28,6 +32,10 @@
     null,
     "Prestať odoberať"
   ],
+  "Upload": [
+    null,
+    "Nahrávanie"
+  ],
   "Upload a file": [
     null,
     "Nahrať súbor"
