@@ -12,6 +12,10 @@
     null,
     "Уређивање"
   ],
+  "Image": [
+    null,
+    "Слика"
+  ],
   "Loading...": [
     null,
     "Учитавање ..."
@@ -20,6 +24,10 @@
     null,
     "URL"
   ],
+  "Upload": [
+    null,
+    "Допреми"
+  ],
   "Upload a file": [
     null,
     "Допреми фајл"
