@@ -13,7 +13,6 @@ CKAN.Utils = CKAN.Utils || {};
     CKAN.Utils.setupUserAutocomplete($('input.autocomplete-user'));
     CKAN.Utils.setupOrganizationUserAutocomplete($('input.autocomplete-organization-user'));
     CKAN.Utils.setupGroupAutocomplete($('input.autocomplete-group'));
-    CKAN.Utils.setupAuthzGroupAutocomplete($('input.autocomplete-authzgroup'));
     CKAN.Utils.setupPackageAutocomplete($('input.autocomplete-dataset'));
     CKAN.Utils.setupTagAutocomplete($('input.autocomplete-tag'));
     $('input.autocomplete-format').live('keyup', function(){
@@ -41,12 +40,12 @@ CKAN.Utils = CKAN.Utils || {};
       CKAN.Utils.setupNotesExtract();
     }
 
-    var isResourceView = $('body.package.resource_read').length > 0;
+    var isResourceView = false; //$('body.package.resource_read').length > 0;
     if (isResourceView) {
       CKAN.DataPreview.loadPreviewDialog(preload_resource);
     }
 
-    var isEmbededDataviewer = $('body.package.resource_embedded_dataviewer').length > 0;
+    var isEmbededDataviewer = false;//$('body.package.resource_embedded_dataviewer').length > 0;
     if (isEmbededDataviewer) {
       CKAN.DataPreview.loadEmbeddedPreview(preload_resource, reclineState);
     }
@@ -1269,26 +1268,6 @@ CKAN.Utils = function($, my) {
     });
   };
 
-  // Attach authz group autocompletion to provided elements
-  //
-  // Requires: jquery-ui autocomplete
-  my.setupAuthzGroupAutocomplete = function(elements) {
-    elements.autocomplete({
-      minLength: 2,
-      source: function(request, callback) {
-        var url = CKAN.SITE_URL + '/api/2/util/authorizationgroup/autocomplete?q=' + request.term;
-        $.getJSON(url, function(data) {
-          $.each(data, function(idx, userobj) {
-            var label = userobj.name;
-            userobj.label = label;
-            userobj.value = userobj.name;
-          });
-          callback(data);
-        });
-      }
-    });
-  };
-
   my.setupGroupAutocomplete = function(elements) {
     elements.autocomplete({
       minLength: 2,
