@@ -26,7 +26,7 @@ class WsgiCkanClient(CkanClient):
 
     def open_url(self, location, data=None, headers={}, method=None):
         if self.is_verbose:
-            self._print("ckanclient: Opening %s" % location)
+            print "ckanclient: Opening %s" % location
         self.last_location = location
 
         if data != None:
@@ -55,31 +55,31 @@ class WsgiCkanClient(CkanClient):
                 raise ClientError('No Paste interface for method \'%s\': %s' % \
                                   (method, location))
         except paste.fixture.AppError, inst:
-            self._print("ckanclient: error: %s" % inst)
+            print "ckanclient: error: %s" % inst
             self.last_http_error = inst
             self.last_status = 500
             self.last_message = repr(inst.args)
         else:
             if res.status not in (200, 201):
-                self._print("ckanclient: Received HTTP error code from CKAN resource.")
-                self._print("ckanclient: location: %s" % location)
-                self._print("ckanclient: response code: %s" % res.status)
-                self._print("ckanclient: request headers: %s" % headers)
-                self._print("ckanclient: request data: %s" % data)
-                self._print("ckanclient: error: %s" % res)
+                print "ckanclient: Received HTTP error code from CKAN resource."
+                print "ckanclient: location: %s" % location
+                print "ckanclient: response code: %s" % res.status
+                print "ckanclient: request headers: %s" % headers
+                print "ckanclient: request data: %s" % data
+                print "ckanclient: error: %s" % res
                 self.last_http_error = res
                 self.last_status = res.status
                 self.last_message = res.body
             else:
-                self._print("ckanclient: OK opening CKAN resource: %s" % location)
+                print "ckanclient: OK opening CKAN resource: %s" % location
                 self.last_status = res.status
-                self._print('ckanclient: last status %s' % self.last_status)
+                print 'ckanclient: last status %s' % self.last_status
                 self.last_body = res.body
-                self._print('ckanclient: last body %s' % self.last_body)
+                print 'ckanclient: last body %s' % self.last_body
                 self.last_headers = dict(res.headers)
-                self._print('ckanclient: last headers %s' % self.last_headers)
+                print 'ckanclient: last headers %s' % self.last_headers
                 content_type = self.last_headers['Content-Type']
-                self._print('ckanclient: content type: %s' % content_type)
+                print 'ckanclient: content type: %s' % content_type
                 is_json_response = False
                 if 'json' in content_type:
                     is_json_response = True
@@ -87,7 +87,7 @@ class WsgiCkanClient(CkanClient):
                     self.last_message = self._loadstr(self.last_body)
                 else:
                     self.last_message = self.last_body
-                self._print('ckanclient: last message %s' % self.last_message)
+                print 'ckanclient: last message %s' % self.last_message
         if self.last_status not in (200, 201):
             raise CkanApiError(self.last_message)
 
