@@ -18,6 +18,8 @@ import psycopg2.extras
 import ckan.lib.cli as cli
 import ckan.plugins.toolkit as toolkit
 
+import ckanext.datastore.helpers as datastore_helpers
+
 log = logging.getLogger(__name__)
 
 if not os.environ.get('DATASTORE_LOAD'):
@@ -621,7 +623,7 @@ def upsert_data(context, data_dict):
 
             for field in fields:
                 value = record.get(field['id'])
-                if value and field['type'].lower() == 'nested':
+                if value is not None and field['type'].lower() == 'nested':
                     ## a tuple with an empty second value
                     record[field['id']] = (json.dumps(value), '')
 
@@ -1151,12 +1153,24 @@ def search_sql(context, data_dict):
     timeout = context.get('query_timeout', _TIMEOUT)
     _cache_types(context)
 
+    sql = data_dict['sql'].replace('%', '%%')
+
     try:
+
         context['connection'].execute(
             u'SET LOCAL statement_timeout TO {0}'.format(timeout))
-        results = context['connection'].execute(
-            data_dict['sql'].replace('%', '%%')
-        )
+
+        table_names = datastore_helpers.get_table_names_from_sql(context, sql)
+        log.debug('Tables involved in input SQL: {0}'.format(table_names))
+
+        system_tables = [t for t in table_names if t.startswith('pg_')]
+        if len(system_tables):
+            raise toolkit.NotAuthorized({
+                'permissions': ['Not authorized to access system tables']
+            })
+
+        results = context['connection'].execute(sql)
+
         return format_results(context, results, data_dict)
 
     except ProgrammingError, e:
@@ -1164,12 +1178,17 @@ def search_sql(context, data_dict):
             raise toolkit.NotAuthorized({
                 'permissions': ['Not authorized to read resource.']
             })
+
+        def _remove_explain(msg):
+            return (msg.replace('EXPLAIN (FORMAT JSON) ', '')
+                       .replace('EXPLAIN ', ''))
+
         raise ValidationError({
-            'query': [str(e)],
+            'query': [_remove_explain(str(e))],
             'info': {
-                'statement': [e.statement],
+                'statement': [_remove_explain(e.statement)],
                 'params': [e.params],
-                'orig': [str(e.orig)]
+                'orig': [_remove_explain(str(e.orig))]
             }
         })
     except DBAPIError, e:
